// SPDX-License-Identifier: MPL-2.0

//! [`Form`].

use crate::prelude::*;

def_subcontrol!(
    docs: "


        # Examples

        ```no_run
        // TODO
        ```
    ",
    ty: Form,
    handle: uiForm,
);

impl Form {}
